Documentation
¶
Index ¶
- Constants
- func Decode(data []byte) (Memory, []SchemaProblem)
- func Discover(root string) (sidecars []string, markdown []string, err error)
- func DiscoverStrict(root string) (sidecars []string, markdown []string, err error)
- func Load(path string) (Memory, []SchemaProblem)
- func LoadUnder(root, rel string) (Memory, []SchemaProblem)
- func ValidateSchemaContract(root string) error
- func ValidateSchemaContractStrict(root string) error
- type Entity
- type Memory
- type Provenance
- type Record
- type Relationship
- type SchemaProblem
- type Source
- type Temporal
Constants ¶
const ExpectedSchemaContractSHA256 = "064ad5ef7fcdaacd086a0bf21ae4de6b62006498f6a451a2fcf7b9bcbdb05f5b"
Variables ¶
This section is empty.
Functions ¶
func Decode ¶
func Decode(data []byte) (Memory, []SchemaProblem)
func DiscoverStrict ¶ added in v0.8.0
DiscoverStrict discovers canonical memory pairs only after proving the whole memories tree is composed of real directories and regular files.
func Load ¶
func Load(path string) (Memory, []SchemaProblem)
func LoadUnder ¶ added in v0.8.0
func LoadUnder(root, rel string) (Memory, []SchemaProblem)
LoadUnder reads a repository-relative memory sidecar without following symbolic links in the repository root, ancestor directories, or final file.
func ValidateSchemaContract ¶
func ValidateSchemaContractStrict ¶ added in v0.8.0
ValidateSchemaContractStrict verifies the vendored schema without following repository-root, ancestor, or leaf symbolic links.
Types ¶
type Memory ¶
type Memory struct {
SchemaVersion int `json:"schema_version"`
ID string `json:"id"`
Title string `json:"title"`
Type string `json:"type"`
Lifecycle string `json:"lifecycle"`
Summary string `json:"summary"`
Projects []string `json:"projects"`
Topics []string `json:"topics"`
Tags []string `json:"tags"`
Aliases []string `json:"aliases"`
Entities []Entity `json:"entities"`
Importance string `json:"importance"`
Temporal Temporal `json:"temporal"`
Provenance Provenance `json:"provenance"`
Relationships []Relationship `json:"relationships"`
ContentPath string `json:"content_path"`
Sensitivity string `json:"sensitivity"`
OpenLoopStatus *string `json:"open_loop_status,omitempty"`
}
type Provenance ¶
type Record ¶
func LoadAllStrict ¶ added in v0.8.0
LoadAllStrict loads all canonical sidecars from a strict memories tree.
type Relationship ¶
type SchemaProblem ¶
func (SchemaProblem) Error ¶
func (p SchemaProblem) Error() string
Click to show internal directories.
Click to hide internal directories.